ChangeLog
=========

1.1.0 (2021-03-29)
------------------

* Added upload-signatures, get-signatures to interact with pyxis sigstore
* Added get-repository-metadata to fetch repository data from pyxis
* Fixed py2.6 pip url

1.0.0 (2020-11-27)
------------------

* Set version to 1.0.0 to indicate stable release

0.2.0 (2020-11-23)
------------------

* Fix module path


0.1.0 (2020-11-20)
------------------

* Initial release.

